@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -710,6 +710,14 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] ETC_UTC = new String[] {
+               "Coordinated Universal Time",
+               "UTC",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Mauritius = new String[] {
                "Standard na Oras sa Mauritius",
                "",
@@ -1257,16 +1265,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
             { "Asia/Shanghai", China },
-            { "UTC",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
+            { "UTC", ETC_UTC },
             { "Asia/Aden", Arabian },
             { "timezone.excity.America/Phoenix", "Phoenix" },
             { "timezone.excity.America/Antigua", "Antigua" },
@@ -1292,6 +1291,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             },
             { "timezone.excity.Antarctica/Vostok", "Vostok" },
             { "America/Panama", America_Eastern },
+            { "JST", Japan },
             { "timezone.excity.Pacific/Fiji", "Fiji" },
             { "timezone.excity.Europe/Gibraltar", "Gibraltar" },
             { "Europe/Jersey", GMT },
@@ -1310,6 +1310,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Tallinn", "Tallinn" },
             { "Asia/Phnom_Penh", Indochina },
             { "Africa/Kigali", Africa_Central },
+            { "BET", Brasilia },
             { "timezone.excity.Pacific/Guam", "Guam" },
             { "timezone.excity.Europe/Vaduz", "Vaduz" },
             { "America/Argentina/Salta", Argentina },
@@ -1495,6 +1496,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "Pacific/Truk", Truk },
             { "timezone.excity.Africa/Conakry", "Conakry" },
             { "timezone.excity.Asia/Jakarta", "Jakarta" },
+            { "SST", Solomon },
             { "America/Jamaica", America_Eastern },
             { "Asia/Bishkek", Kyrgystan },
             { "Atlantic/Stanley", Falkland },
@@ -1515,6 +1517,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "timezone.excity.Indian/Mahe", "Mahe" },
             { "Europe/San_Marino", Europe_Central },
             { "America/Indiana/Tell_City", America_Central },
+            { "BST", Bangladesh },
             { "timezone.excity.Europe/Isle_of_Man", "Isle of Man" },
             { "Pacific/Saipan", Chamorro },
             { "timezone.excity.America/Curacao", "Curacao" },
@@ -1523,6 +1526,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "Antarctica/Rothera", Rothera },
             { "timezone.excity.America/Guyana", "Guyana" },
             { "Asia/Damascus", Europe_Eastern },
+            { "MIT", Apia },
             { "America/Argentina/San_Luis", Argentina_Western },
             { "timezone.excity.Europe/Paris", "Paris" },
             { "timezone.excity.Europe/Zagreb", "Zagreb" },
@@ -1540,16 +1544,6 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Chita", "Chita" },
             { "America/Indiana/Marengo", America_Eastern },
             { "timezone.excity.America/Rankin_Inlet", "Makipot na Look ng Rankin" },
-            { "America/Punta_Arenas",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "timezone.excity.America/Santarem", "Santarem" },
             { "timezone.excity.Asia/Tomsk", "Tomsk" },
             { "timezone.excity.Europe/Helsinki", "Helsinki" },
@@ -1634,17 +1628,8 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "Europe/Tallinn", Europe_Eastern },
             { "Africa/Johannesburg", Africa_Southern },
             { "timezone.excity.Pacific/Fakaofo", "Fakaofo" },
+            { "EAT", Africa_Eastern },
             { "Africa/Bangui", Africa_Western },
-            { "Europe/Astrakhan",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Africa/Juba", Africa_Eastern },
             { "America/Campo_Grande", Amazon },
             { "America/Belem", Brasilia },
@@ -1665,6 +1650,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "America/Whitehorse", America_Pacific },
             { "timezone.excity.America/Cuiaba", "Cuiaba" },
             { "Pacific/Noumea", New_Caledonia },
+            { "ECT", Europe_Central },
             { "timezone.excity.Atlantic/Azores", "Azores" },
             { "timezone.excity.Australia/Melbourne", "Melbourne" },
             { "America/Montreal", America_Eastern },
@@ -1692,6 +1678,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "timezone.excity.America/Regina", "Regina" },
             { "SystemV/YST9YDT", Alaska },
             { "America/Merida", America_Central },
+            { "CAT", Africa_Central },
             { "America/St_Kitts", Atlantic },
             { "timezone.excity.America/Thunder_Bay", "Thunder Bay" },
             { "America/Fort_Nelson", America_Mountain },
@@ -1715,16 +1702,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "Europe/Vatican", Europe_Central },
             { "timezone.excity.America/Asuncion", "Asunci\u00f3n" },
             { "Asia/Amman", Europe_Eastern },
-            { "Etc/UTC",
-                new String[] {
-                    "Coordinated Universal Time",
-                    "UTC",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
+            { "Etc/UTC", ETC_UTC },
             { "timezone.excity.Europe/Chisinau", "Chisinau" },
             { "timezone.excity.America/Moncton", "Moncton" },
             { "Asia/Singapore", Singapore },
@@ -1778,6 +1756,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "Europe/Isle_of_Man", GMT },
             { "America/Araguaina", Brasilia },
             { "timezone.excity.Pacific/Easter", "Easter" },
+            { "ACT", Australia_Central },
             { "Asia/Novosibirsk", Novosibirsk },
             { "Africa/Tunis", Europe_Central },
             { "Pacific/Fakaofo", Tokelau },
@@ -1804,6 +1783,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Kirov", "Kirov" },
             { "timezone.excity.America/Creston", "Creston" },
             { "timezone.excity.Africa/Cairo", "Cairo" },
+            { "AET", Australia_Eastern },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "timezone.excity.Europe/Warsaw", "Warsaw" },
             { "Europe/Skopje", Europe_Central },
@@ -1813,16 +1793,6 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "Africa/Algiers", Europe_Central },
             { "Europe/Mariehamn", Europe_Eastern },
             { "America/Anguilla", Atlantic },
-            { "Europe/Saratov",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Europe/Gibraltar", Europe_Central },
             { "Africa/Conakry", GMT },
             { "America/Havana", Cuba },
@@ -1859,16 +1829,6 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "America/Port_of_Spain", Atlantic },
             { "Asia/Beirut", Europe_Eastern },
             { "timezone.excity.Asia/Baghdad", "Baghdad" },
-            { "Pacific/Bougainville",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Africa/Sao_Tome", Africa_Western },
             { "Indian/Chagos", Indian_Ocean },
             { "timezone.excity.America/Metlakatla", "Metlakatla" },
@@ -1880,6 +1840,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "timezone.excity.America/Panama", "Panama" },
             { "timezone.excity.Europe/Simferopol", "Simferopol" },
             { "timezone.excity.Indian/Kerguelen", "Kerguelen" },
+            { "CNT", Newfoundland },
             { "timezone.excity.Europe/Volgograd", "Volgograd" },
             { "timezone.excity.Europe/Monaco", "Monaco" },
             { "Asia/Tashkent", Uzbekistan },
@@ -1901,6 +1862,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "timezone.excity.America/Managua", "Managua" },
             { "America/Kralendijk", Atlantic },
             { "Indian/Christmas", Christmas },
+            { "NET", Armenia },
             { "America/Inuvik", America_Mountain },
             { "America/Iqaluit", America_Eastern },
             { "Pacific/Funafuti", Tuvalu },
@@ -1942,11 +1904,13 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "Asia/Chongqing", China },
             { "America/Indiana/Knox", America_Central },
             { "timezone.excity.Asia/Saigon", "Lungsod ng Ho Chi Minh" },
+            { "PLT", Pakistan },
             { "America/North_Dakota/Beulah", America_Central },
             { "timezone.excity.Asia/Makassar", "Makassar" },
             { "Pacific/Apia", Apia },
             { "Pacific/Niue", Niue },
             { "timezone.excity.Asia/Yekaterinburg", "Yekaterinburg" },
+            { "CST", America_Central },
             { "timezone.excity.Europe/Sofia", "Sofia" },
             { "MST7MDT", America_Mountain },
             { "America/Monterrey", America_Central },
@@ -1958,6 +1922,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "timezone.excity.America/Denver", "Denver" },
             { "Indian/Mahe", Seychelles },
             { "Asia/Aqtobe", Kazakhstan_Western },
+            { "CTT", China },
             { "timezone.excity.Asia/Gaza", "Gaza" },
             { "timezone.excity.Africa/Ceuta", "Ceuta" },
             { "Africa/Libreville", Africa_Western },
@@ -1967,6 +1932,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "timezone.excity.Antarctica/Troll", "Troll" },
             { "America/Aruba", Atlantic },
             { "America/North_Dakota/Center", America_Central },
+            { "PNT", America_Mountain },
             { "timezone.excity.Asia/Hong_Kong", "Hong Kong" },
             { "timezone.excity.America/Port-au-Prince", "Port-au-Prince" },
             { "America/Tijuana", America_Pacific },
@@ -1984,6 +1950,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "America/Santiago", Chile },
             { "timezone.excity.Europe/Zaporozhye", "Zaporozhye" },
             { "Asia/Baku", Azerbaijan },
+            { "ART", Europe_Eastern },
             { "America/Argentina/Ushuaia", Argentina },
             { "Atlantic/Reykjavik", GMT },
             { "Africa/Brazzaville", Africa_Western },
@@ -1994,17 +1961,8 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "timezone.excity.Africa/Kampala", "Kampala" },
             { "timezone.excity.Pacific/Chatham", "Chatham" },
             { "Africa/Dar_es_Salaam", Africa_Eastern },
-            { "Antarctica/Palmer",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Africa/Addis_Ababa", Africa_Eastern },
+            { "AST", Alaska },
             { "Europe/Uzhgorod", Europe_Eastern },
             { "timezone.excity.Asia/Colombo", "Colombo" },
             { "timezone.excity.Pacific/Port_Moresby", "Port Moresby" },
@@ -2022,6 +1980,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "Atlantic/South_Georgia", South_Georgia },
             { "Europe/Lisbon", Europe_Western },
             { "Asia/Harbin", China },
+            { "PRT", Atlantic },
             { "Asia/Novokuznetsk", Krasnoyarsk },
             { "timezone.excity.America/Cordoba", "Cordoba" },
             { "timezone.excity.America/Cambridge_Bay", "Cambridge Bay" },
@@ -2041,6 +2000,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "timezone.excity.Australia/Sydney", "Sydney" },
             { "timezone.excity.Asia/Qatar", "Qatar" },
             { "timezone.excity.America/Sitka", "Sitka" },
+            { "PST", America_Pacific },
             { "SystemV/EST5", America_Eastern },
             { "timezone.excity.Antarctica/Davis", "Davis" },
             { "America/Santo_Domingo", Atlantic },
@@ -2092,6 +2052,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "America/Porto_Velho", Amazon },
             { "America/Scoresbysund", Greenland_Eastern },
             { "Asia/Kamchatka", Kamchatka },
+            { "NST", New_Zealand },
             { "timezone.excity.Asia/Samarkand", "Samarkand" },
             { "Africa/Khartoum", Africa_Central },
             { "timezone.excity.Australia/Adelaide", "Adelaide" },
@@ -2138,31 +2099,11 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "Asia/Atyrau", Kazakhstan_Western },
             { "Australia/Darwin", Australia_Central },
             { "Asia/Kuala_Lumpur", Malaysia },
-            { "Asia/Famagusta",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Europe/Bratislava", Europe_Central },
             { "timezone.excity.Atlantic/Stanley", "Stanley" },
             { "Pacific/Tongatapu", Tonga },
             { "timezone.excity.Asia/Rangoon", "Rangoon" },
             { "timezone.excity.Asia/Thimphu", "Thimphu" },
-            { "Europe/Ulyanovsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "timezone.excity.Asia/Dubai", "Dubai" },
             { "Arctic/Longyearbyen", Europe_Central },
             { "timezone.excity.Asia/Kuala_Lumpur", "Kuala Lumpur" },
@@ -2170,16 +2111,6 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "Indian/Kerguelen", French_Southern },
             { "timezone.excity.Africa/Ouagadougou", "Ouagadougou" },
             { "timezone.excity.Africa/Gaborone", "Gaborone" },
-            { "Asia/Srednekolymsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Asia/Anadyr", Anadyr },
             { "timezone.excity.Indian/Chagos", "Chagos" },
             { "timezone.excity.Asia/Kabul", "Kabul" },
