@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -902,6 +902,14 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
                "Iraanske tiid",
                "",
             };
+        final String[] EMPTY_ZONE = new String[] {
+               "",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Easter = new String[] {
                "Peaskeeil\u00e2nske standerttiid",
                "",
@@ -1233,16 +1241,7 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
             { "Asia/Shanghai", China },
-            { "UTC",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
+            { "UTC", EMPTY_ZONE },
             { "Asia/Aden", Arabian },
             { "America/Cuiaba", Amazon },
             { "Africa/Nairobi", Africa_Eastern },
@@ -1277,6 +1276,7 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             { "America/Indiana/Petersburg", America_Eastern },
             { "Asia/Yerevan", Armenia },
             { "Europe/Brussels", Europe_Central },
+            { "JST", Japan },
             { "timezone.excity.Asia/Kamchatka", "Kamtsjatka" },
             { "Europe/Warsaw", Europe_Central },
             { "Pacific/Yap", Truk },
@@ -1301,8 +1301,10 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             { "timezone.excity.America/El_Salvador", "Salvador" },
             { "Asia/Dubai", Gulf },
             { "Europe/Isle_of_Man", GMT },
+            { "BET", Brasilia },
             { "America/Araguaina", Brasilia },
             { "timezone.excity.Pacific/Easter", "Peaskeeil\u00e2n" },
+            { "ACT", Australia_Central },
             { "Asia/Novosibirsk", Novosibirsk },
             { "America/Argentina/Salta", Argentina },
             { "Africa/Tunis", Europe_Central },
@@ -1337,6 +1339,7 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             { "Africa/Asmera", Africa_Eastern },
             { "Europe/Busingen", Europe_Central },
             { "timezone.excity.Africa/Cairo", "Ca\u00efro" },
+            { "AET", Australia_Eastern },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "Africa/Malabo", Africa_Western },
             { "timezone.excity.Europe/Warsaw", "Warschau" },
@@ -1358,16 +1361,6 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             { "America/Anguilla", Atlantic },
             { "Asia/Dili", East_Timor },
             { "Africa/Bamako", GMT },
-            { "Europe/Saratov",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Pacific/Wallis", Wallis },
             { "Europe/Gibraltar", Europe_Central },
             { "Africa/Conakry", GMT },
@@ -1411,16 +1404,6 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             { "Europe/Helsinki", Europe_Eastern },
             { "Asia/Beirut", Europe_Eastern },
             { "timezone.excity.Asia/Baghdad", "Bagdad" },
-            { "Pacific/Bougainville",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Africa/Sao_Tome", Africa_Western },
             { "Indian/Chagos", Indian_Ocean },
             { "America/Cayenne", French_Guiana },
@@ -1437,6 +1420,7 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             { "America/Yellowknife", America_Mountain },
             { "Pacific/Enderbury", Phoenix_Islands },
             { "America/Juneau", Alaska },
+            { "CNT", Newfoundland },
             { "America/Indiana/Vevay", America_Eastern },
             { "timezone.excity.Europe/Volgograd", "Wolgograd" },
             { "timezone.excity.Asia/Phnom_Penh", "Phnom-Penh" },
@@ -1469,6 +1453,7 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             { "Europe/Samara", Samara },
             { "Indian/Christmas", Christmas },
             { "America/Antigua", Atlantic },
+            { "NET", Armenia },
             { "timezone.excity.America/Sao_Paulo", "S\u00e3o Paulo" },
             { "Pacific/Gambier", Gambier },
             { "America/Inuvik", America_Mountain },
@@ -1522,11 +1507,13 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             { "timezone.excity.America/Argentina/Tucuman", "Tucum\u00e1n" },
             { "America/Indiana/Knox", America_Central },
             { "timezone.excity.Asia/Saigon", "Ho Chi Minhstad" },
+            { "PLT", Pakistan },
             { "America/North_Dakota/Beulah", America_Central },
             { "Africa/Accra", GMT },
             { "America/Maceio", Brasilia },
             { "Pacific/Niue", Niue },
             { "timezone.excity.Asia/Yekaterinburg", "Jekaterinenburg" },
+            { "CST", America_Central },
             { "Australia/Lord_Howe", Lord_Howe },
             { "Europe/Dublin",
                 new String[] {
@@ -1542,6 +1529,7 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             { "MST7MDT", America_Mountain },
             { "America/Monterrey", America_Central },
             { "America/Nassau", America_Eastern },
+            { "SST", Solomon },
             { "America/Jamaica", America_Eastern },
             { "Asia/Bishkek", Kyrgystan },
             { "Atlantic/Stanley", Falkland },
@@ -1550,6 +1538,7 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Calcutta", "Calcutta" },
             { "Indian/Mahe", Seychelles },
             { "Asia/Aqtobe", Kazakhstan_Western },
+            { "CTT", China },
             { "timezone.excity.Asia/Aqtobe", "Aqt\u00f6be" },
             { "Asia/Vladivostok", Vladivostok },
             { "Africa/Libreville", Africa_Western },
@@ -1563,6 +1552,7 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             { "America/Aruba", Atlantic },
             { "timezone.excity.Europe/Luxembourg", "Luxemburg" },
             { "America/North_Dakota/Center", America_Central },
+            { "PNT", America_Mountain },
             { "America/Cayman", America_Eastern },
             { "Asia/Ulaanbaatar", Mongolia },
             { "Asia/Baghdad", Arabian },
@@ -1571,6 +1561,7 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             { "timezone.excity.Indian/Mahe", "Mah\u00e9" },
             { "Europe/San_Marino", Europe_Central },
             { "America/Indiana/Tell_City", America_Central },
+            { "BST", Bangladesh },
             { "America/Tijuana", America_Pacific },
             { "timezone.excity.America/Mexico_City", "Mexico-stad" },
             { "Pacific/Saipan", Chamorro },
@@ -1588,6 +1579,7 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             { "America/Santiago", Chile },
             { "timezone.excity.Europe/Zaporozhye", "Zaporizja" },
             { "Asia/Baku", Azerbaijan },
+            { "ART", Europe_Eastern },
             { "America/Argentina/Ushuaia", Argentina },
             { "Atlantic/Reykjavik", GMT },
             { "Africa/Brazzaville", Africa_Western },
@@ -1600,32 +1592,13 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             { "Asia/Bangkok", Indochina },
             { "Africa/Dar_es_Salaam", Africa_Eastern },
             { "Atlantic/Madeira", Europe_Western },
-            { "Antarctica/Palmer",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "America/Thunder_Bay", America_Eastern },
             { "timezone.excity.Europe/Budapest", "Boedapest" },
             { "Africa/Addis_Ababa", Africa_Eastern },
+            { "AST", Alaska },
             { "Europe/Uzhgorod", Europe_Eastern },
             { "America/Indiana/Marengo", America_Eastern },
             { "America/Creston", America_Mountain },
-            { "America/Punta_Arenas",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "America/Mexico_City", America_Central },
             { "Antarctica/Vostok", Vostok },
             { "Europe/Andorra", Europe_Central },
@@ -1638,6 +1611,7 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             { "Atlantic/South_Georgia", South_Georgia },
             { "Europe/Lisbon", Europe_Western },
             { "Asia/Harbin", China },
+            { "PRT", Atlantic },
             { "Europe/Oslo", Europe_Central },
             { "Asia/Novokuznetsk", Krasnoyarsk },
             { "timezone.excity.America/Cordoba", "C\u00f3rdoba" },
@@ -1658,6 +1632,7 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             { "Africa/Kampala", Africa_Eastern },
             { "Asia/Krasnoyarsk", Krasnoyarsk },
             { "timezone.excity.Asia/Kuwait", "Koeweit" },
+            { "PST", America_Pacific },
             { "SystemV/EST5", America_Eastern },
             { "America/Edmonton", America_Mountain },
             { "Europe/Podgorica", Europe_Central },
@@ -1731,24 +1706,16 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             { "Asia/Kamchatka", Kamchatka },
             { "Africa/Harare", Africa_Central },
             { "America/Nome", Alaska },
+            { "NST", New_Zealand },
             { "Europe/Tallinn", Europe_Eastern },
             { "Africa/Khartoum", Africa_Central },
             { "Africa/Johannesburg", Africa_Southern },
+            { "EAT", Africa_Eastern },
             { "Africa/Bangui", Africa_Western },
             { "Europe/Belgrade", Europe_Central },
             { "timezone.excity.Europe/Vienna", "Wenen" },
             { "Africa/Bissau", GMT },
             { "Asia/Tehran", Iran },
-            { "Europe/Astrakhan",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Africa/Juba", Africa_Eastern },
             { "America/Campo_Grande", Amazon },
             { "America/Belem", Brasilia },
@@ -1770,6 +1737,7 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             { "timezone.excity.America/Cuiaba", "Cuiab\u00e1" },
             { "Pacific/Noumea", New_Caledonia },
             { "Asia/Tbilisi", Georgia },
+            { "ECT", Europe_Central },
             { "timezone.excity.Atlantic/Azores", "Azoren" },
             { "timezone.excity.Asia/Ashgabat", "Asjchabad" },
             { "America/Montreal", America_Eastern },
@@ -1787,16 +1755,6 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             { "Asia/Khandyga", Yakutsk },
             { "Asia/Kuala_Lumpur", Malaysia },
             { "Asia/Thimphu", Bhutan },
-            { "Asia/Famagusta",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Asia/Rangoon", Myanmar },
             { "Europe/Bratislava", Europe_Central },
             { "timezone.excity.Indian/Christmas", "Krysteil\u00e2n" },
@@ -1806,17 +1764,8 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             { "Indian/Cocos", Cocos },
             { "Pacific/Tongatapu", Tonga },
             { "SystemV/YST9YDT", Alaska },
-            { "Europe/Ulyanovsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "America/Merida", America_Central },
+            { "CAT", Africa_Central },
             { "America/St_Kitts", Atlantic },
             { "Arctic/Longyearbyen", Europe_Central },
             { "America/Fort_Nelson", America_Mountain },
@@ -1827,16 +1776,6 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             { "SystemV/PST8PDT", America_Pacific },
             { "Africa/Monrovia", GMT },
             { "Asia/Ust-Nera", Vladivostok },
-            { "Asia/Srednekolymsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "America/North_Dakota/New_Salem", America_Central },
             { "Asia/Anadyr", Anadyr },
             { "Australia/Melbourne", Australia_Eastern },
