@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -710,6 +710,14 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] ETC_UTC = new String[] {
+               "Koordinatali universal vaqt",
+               "UTC",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Mauritius = new String[] {
                "Mavrikiy standart vaqti",
                "",
@@ -1233,16 +1241,7 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
             { "Asia/Shanghai", China },
-            { "UTC",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
+            { "UTC", ETC_UTC },
             { "Asia/Aden", Arabian },
             { "timezone.excity.America/Phoenix", "Feniks" },
             { "timezone.excity.Asia/Katmandu", "Katmandu" },
@@ -1270,6 +1269,7 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
             { "timezone.excity.Antarctica/Vostok", "Vostok" },
             { "America/Panama", America_Eastern },
             { "timezone.excity.America/North_Dakota/Beulah", "Boyla, Shimoliy Dakota" },
+            { "JST", Japan },
             { "timezone.excity.Pacific/Fiji", "Fiji" },
             { "timezone.excity.Europe/Gibraltar", "Gibraltar" },
             { "Europe/Jersey", GMT },
@@ -1289,6 +1289,7 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
             { "timezone.excity.Pacific/Truk", "Truk orollari" },
             { "Asia/Phnom_Penh", Indochina },
             { "Africa/Kigali", Africa_Central },
+            { "BET", Brasilia },
             { "timezone.excity.Pacific/Guam", "Guam" },
             { "timezone.excity.Europe/Vaduz", "Vaduts" },
             { "America/Argentina/Salta", Argentina },
@@ -1480,6 +1481,7 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
             { "Pacific/Truk", Truk },
             { "timezone.excity.Africa/Conakry", "Konakri" },
             { "timezone.excity.Asia/Jakarta", "Jakarta" },
+            { "SST", Solomon },
             { "America/Jamaica", America_Eastern },
             { "Asia/Bishkek", Kyrgystan },
             { "Atlantic/Stanley", Falkland },
@@ -1501,6 +1503,7 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
             { "timezone.excity.Indian/Mahe", "Mae" },
             { "Europe/San_Marino", Europe_Central },
             { "America/Indiana/Tell_City", America_Central },
+            { "BST", Bangladesh },
             { "timezone.excity.Europe/Isle_of_Man", "Men oroli" },
             { "Pacific/Saipan", Chamorro },
             { "timezone.excity.America/Curacao", "Kyurasao" },
@@ -1509,6 +1512,7 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
             { "Antarctica/Rothera", Rothera },
             { "timezone.excity.America/Guyana", "Gayana" },
             { "Asia/Damascus", Europe_Eastern },
+            { "MIT", Apia },
             { "America/Argentina/San_Luis", Argentina_Western },
             { "timezone.excity.Europe/Paris", "Parij" },
             { "timezone.excity.Europe/Zagreb", "Zagreb" },
@@ -1528,16 +1532,6 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Chita", "Chita" },
             { "America/Indiana/Marengo", America_Eastern },
             { "timezone.excity.America/Rankin_Inlet", "Rankin-Inlet" },
-            { "America/Punta_Arenas",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "timezone.excity.America/Santarem", "Santarem" },
             { "timezone.excity.Asia/Tomsk", "Tomsk" },
             { "timezone.excity.Europe/Helsinki", "Xelsinki" },
@@ -1623,17 +1617,8 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
             { "Europe/Tallinn", Europe_Eastern },
             { "Africa/Johannesburg", Africa_Southern },
             { "timezone.excity.Pacific/Fakaofo", "Fakaofo" },
+            { "EAT", Africa_Eastern },
             { "Africa/Bangui", Africa_Western },
-            { "Europe/Astrakhan",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Africa/Juba", Africa_Eastern },
             { "America/Campo_Grande", Amazon },
             { "America/Belem", Brasilia },
@@ -1654,6 +1639,7 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
             { "America/Whitehorse", America_Pacific },
             { "timezone.excity.America/Cuiaba", "Kuyaba" },
             { "Pacific/Noumea", New_Caledonia },
+            { "ECT", Europe_Central },
             { "timezone.excity.Atlantic/Azores", "Azor orollari" },
             { "timezone.excity.Australia/Melbourne", "Melburn" },
             { "America/Montreal", America_Eastern },
@@ -1681,6 +1667,7 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
             { "timezone.excity.America/Regina", "Rejayna" },
             { "SystemV/YST9YDT", Alaska },
             { "America/Merida", America_Central },
+            { "CAT", Africa_Central },
             { "America/St_Kitts", Atlantic },
             { "timezone.excity.America/Thunder_Bay", "Tander-Bey" },
             { "America/Fort_Nelson", America_Mountain },
@@ -1704,16 +1691,7 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
             { "Europe/Vatican", Europe_Central },
             { "timezone.excity.America/Asuncion", "Asunson" },
             { "Asia/Amman", Europe_Eastern },
-            { "Etc/UTC",
-                new String[] {
-                    "Koordinatali universal vaqt",
-                    "UTC",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
+            { "Etc/UTC", ETC_UTC },
             { "timezone.excity.Europe/Chisinau", "Kishinyov" },
             { "timezone.excity.America/Moncton", "Monkton" },
             { "Asia/Singapore", Singapore },
@@ -1769,6 +1747,7 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
             { "Europe/Isle_of_Man", GMT },
             { "America/Araguaina", Brasilia },
             { "timezone.excity.Pacific/Easter", "Pasxa oroli" },
+            { "ACT", Australia_Central },
             { "Asia/Novosibirsk", Novosibirsk },
             { "Africa/Tunis", Europe_Central },
             { "Pacific/Fakaofo", Tokelau },
@@ -1795,6 +1774,7 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Kirov", "Kirov" },
             { "timezone.excity.America/Creston", "Kreston" },
             { "timezone.excity.Africa/Cairo", "Qohira" },
+            { "AET", Australia_Eastern },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "timezone.excity.Europe/Warsaw", "Varshava" },
             { "Europe/Skopje", Europe_Central },
@@ -1805,16 +1785,6 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
             { "Africa/Algiers", Europe_Central },
             { "Europe/Mariehamn", Europe_Eastern },
             { "America/Anguilla", Atlantic },
-            { "Europe/Saratov",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Europe/Gibraltar", Europe_Central },
             { "Africa/Conakry", GMT },
             { "America/Havana", Cuba },
@@ -1853,16 +1823,6 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
             { "Asia/Beirut", Europe_Eastern },
             { "timezone.excity.Asia/Baghdad", "Bag\u2018dod" },
             { "timezone.excity.Antarctica/DumontDUrville", "Dyumon-d\u2019Yurvil" },
-            { "Pacific/Bougainville",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Africa/Sao_Tome", Africa_Western },
             { "Indian/Chagos", Indian_Ocean },
             { "timezone.excity.America/Metlakatla", "Metlakatla" },
@@ -1875,6 +1835,7 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
             { "timezone.excity.America/Panama", "Panama" },
             { "timezone.excity.Europe/Simferopol", "Simferopol" },
             { "timezone.excity.Indian/Kerguelen", "Kergelen" },
+            { "CNT", Newfoundland },
             { "timezone.excity.Europe/Volgograd", "Volgograd" },
             { "timezone.excity.Europe/Monaco", "Monako" },
             { "Asia/Tashkent", Uzbekistan },
@@ -1897,6 +1858,7 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
             { "timezone.excity.America/Managua", "Managua" },
             { "America/Kralendijk", Atlantic },
             { "Indian/Christmas", Christmas },
+            { "NET", Armenia },
             { "America/Inuvik", America_Mountain },
             { "America/Iqaluit", America_Eastern },
             { "Pacific/Funafuti", Tuvalu },
@@ -1939,11 +1901,13 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
             { "Asia/Chongqing", China },
             { "America/Indiana/Knox", America_Central },
             { "timezone.excity.Asia/Saigon", "Xoshimin" },
+            { "PLT", Pakistan },
             { "America/North_Dakota/Beulah", America_Central },
             { "timezone.excity.Asia/Makassar", "Makasar" },
             { "Pacific/Apia", Apia },
             { "Pacific/Niue", Niue },
             { "timezone.excity.Asia/Yekaterinburg", "Yekaterinburg" },
+            { "CST", America_Central },
             { "timezone.excity.Europe/Sofia", "Sofiya" },
             { "MST7MDT", America_Mountain },
             { "America/Monterrey", America_Central },
@@ -1956,6 +1920,7 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Calcutta", "Kalkutta" },
             { "Indian/Mahe", Seychelles },
             { "Asia/Aqtobe", Kazakhstan_Western },
+            { "CTT", China },
             { "timezone.excity.Asia/Gaza", "G\u2018azo" },
             { "timezone.excity.Africa/Ceuta", "Seuta" },
             { "Africa/Libreville", Africa_Western },
@@ -1965,6 +1930,7 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
             { "timezone.excity.Antarctica/Troll", "Troll" },
             { "America/Aruba", Atlantic },
             { "America/North_Dakota/Center", America_Central },
+            { "PNT", America_Mountain },
             { "timezone.excity.Asia/Hong_Kong", "Gonkong" },
             { "timezone.excity.America/Port-au-Prince", "Port-o-Prens" },
             { "America/Tijuana", America_Pacific },
@@ -1982,6 +1948,7 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
             { "America/Santiago", Chile },
             { "timezone.excity.Europe/Zaporozhye", "Zaporojye" },
             { "Asia/Baku", Azerbaijan },
+            { "ART", Europe_Eastern },
             { "America/Argentina/Ushuaia", Argentina },
             { "Atlantic/Reykjavik", GMT },
             { "Africa/Brazzaville", Africa_Western },
@@ -1992,17 +1959,8 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
             { "timezone.excity.Africa/Kampala", "Kampala" },
             { "timezone.excity.Pacific/Chatham", "Chatem oroli" },
             { "Africa/Dar_es_Salaam", Africa_Eastern },
-            { "Antarctica/Palmer",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Africa/Addis_Ababa", Africa_Eastern },
+            { "AST", Alaska },
             { "Europe/Uzhgorod", Europe_Eastern },
             { "timezone.excity.Asia/Colombo", "Kolombo" },
             { "timezone.excity.Pacific/Port_Moresby", "Port-Morsbi" },
@@ -2020,6 +1978,7 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
             { "Atlantic/South_Georgia", South_Georgia },
             { "Europe/Lisbon", Europe_Western },
             { "Asia/Harbin", China },
+            { "PRT", Atlantic },
             { "Asia/Novokuznetsk", Krasnoyarsk },
             { "timezone.excity.America/Cordoba", "Kordoba" },
             { "timezone.excity.America/Cambridge_Bay", "Kembrij-Bey" },
@@ -2039,6 +1998,7 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
             { "timezone.excity.Australia/Sydney", "Sidney" },
             { "timezone.excity.Asia/Qatar", "Qatar" },
             { "timezone.excity.America/Sitka", "Sitka" },
+            { "PST", America_Pacific },
             { "SystemV/EST5", America_Eastern },
             { "timezone.excity.Antarctica/Davis", "Deyvis" },
             { "America/Santo_Domingo", Atlantic },
@@ -2091,6 +2051,7 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
             { "America/Tortola", Atlantic },
             { "America/Porto_Velho", Amazon },
             { "America/Scoresbysund", Greenland_Eastern },
+            { "NST", New_Zealand },
             { "timezone.excity.Asia/Samarkand", "Samarqand" },
             { "Africa/Khartoum", Africa_Central },
             { "timezone.excity.Australia/Adelaide", "Adelaida" },
@@ -2138,31 +2099,11 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
             { "Asia/Atyrau", Kazakhstan_Western },
             { "Australia/Darwin", Australia_Central },
             { "Asia/Kuala_Lumpur", Malaysia },
-            { "Asia/Famagusta",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Europe/Bratislava", Europe_Central },
             { "timezone.excity.Atlantic/Stanley", "Stenli" },
             { "Pacific/Tongatapu", Tonga },
             { "timezone.excity.Asia/Rangoon", "Rangun" },
             { "timezone.excity.Asia/Thimphu", "Thimphu" },
-            { "Europe/Ulyanovsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "timezone.excity.Asia/Dubai", "Dubay" },
             { "Arctic/Longyearbyen", Europe_Central },
             { "timezone.excity.Asia/Kuala_Lumpur", "Kuala-Lumpur" },
@@ -2170,16 +2111,6 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
             { "Indian/Kerguelen", French_Southern },
             { "timezone.excity.Africa/Ouagadougou", "Uagadugu" },
             { "timezone.excity.Africa/Gaborone", "Gaborone" },
-            { "Asia/Srednekolymsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "timezone.excity.Indian/Chagos", "Chagos" },
             { "timezone.excity.Asia/Kabul", "Qobul" },
             { "timezone.excity.America/Iqaluit", "Ikaluit" },
