@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -886,6 +886,14 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
                "\u042d\u0440\u043e\u043d \u0432\u0430\u049b\u0442\u0438",
                "",
             };
+        final String[] EMPTY_ZONE = new String[] {
+               "",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Easter = new String[] {
                "\u041f\u0430\u0441\u0445\u0438 \u043e\u0440\u043e\u043b\u0438 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
                "",
@@ -1201,16 +1209,7 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
             { "Asia/Shanghai", China },
-            { "UTC",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
+            { "UTC", EMPTY_ZONE },
             { "Asia/Aden", Arabian },
             { "America/Cuiaba", Amazon },
             { "Africa/Nairobi", Africa_Eastern },
@@ -1242,6 +1241,7 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "America/Indiana/Petersburg", America_Eastern },
             { "Asia/Yerevan", Armenia },
             { "Europe/Brussels", Europe_Central },
+            { "JST", Japan },
             { "Europe/Warsaw", Europe_Central },
             { "Pacific/Yap", Truk },
             { "Europe/Jersey", GMT },
@@ -1258,7 +1258,9 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Dubai", Gulf },
             { "Europe/Isle_of_Man", GMT },
+            { "BET", Brasilia },
             { "America/Araguaina", Brasilia },
+            { "ACT", Australia_Central },
             { "Asia/Novosibirsk", Novosibirsk },
             { "America/Argentina/Salta", Argentina },
             { "Africa/Tunis", Europe_Central },
@@ -1288,6 +1290,7 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "Pacific/Tahiti", Tahiti },
             { "Africa/Asmera", Africa_Eastern },
             { "Europe/Busingen", Europe_Central },
+            { "AET", Australia_Eastern },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "Africa/Malabo", Africa_Western },
             { "Europe/Skopje", Europe_Central },
@@ -1307,16 +1310,6 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "America/Anguilla", Atlantic },
             { "Asia/Dili", East_Timor },
             { "Africa/Bamako", GMT },
-            { "Europe/Saratov",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Pacific/Wallis", Wallis },
             { "Europe/Gibraltar", Europe_Central },
             { "Africa/Conakry", GMT },
@@ -1354,16 +1347,6 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "America/Port_of_Spain", Atlantic },
             { "Europe/Helsinki", Europe_Eastern },
             { "Asia/Beirut", Europe_Eastern },
-            { "Pacific/Bougainville",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Africa/Sao_Tome", Africa_Western },
             { "Indian/Chagos", Indian_Ocean },
             { "America/Cayenne", French_Guiana },
@@ -1378,6 +1361,7 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "America/Yellowknife", America_Mountain },
             { "Pacific/Enderbury", Phoenix_Islands },
             { "America/Juneau", Alaska },
+            { "CNT", Newfoundland },
             { "America/Indiana/Vevay", America_Eastern },
             { "Asia/Tashkent", Uzbekistan },
             { "Asia/Jakarta", Indonesia_Western },
@@ -1400,6 +1384,7 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "Antarctica/Troll", GMT },
             { "Indian/Christmas", Christmas },
             { "America/Antigua", Atlantic },
+            { "NET", Armenia },
             { "Pacific/Gambier", Gambier },
             { "America/Inuvik", America_Mountain },
             { "America/Iqaluit", America_Eastern },
@@ -1439,10 +1424,12 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "Asia/Chongqing", China },
             { "Europe/Amsterdam", Europe_Central },
             { "America/Indiana/Knox", America_Central },
+            { "PLT", Pakistan },
             { "America/North_Dakota/Beulah", America_Central },
             { "Africa/Accra", GMT },
             { "America/Maceio", Brasilia },
             { "Pacific/Niue", Niue },
+            { "CST", America_Central },
             { "Australia/Lord_Howe", Lord_Howe },
             { "Europe/Dublin",
                 new String[] {
@@ -1458,12 +1445,14 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "MST7MDT", America_Mountain },
             { "America/Monterrey", America_Central },
             { "America/Nassau", America_Eastern },
+            { "SST", Solomon },
             { "America/Jamaica", America_Eastern },
             { "Asia/Bishkek", Kyrgystan },
             { "Atlantic/Stanley", Falkland },
             { "SystemV/CST6", America_Central },
             { "Indian/Mahe", Seychelles },
             { "Asia/Aqtobe", Kazakhstan_Western },
+            { "CTT", China },
             { "Asia/Vladivostok", Vladivostok },
             { "Africa/Libreville", Africa_Western },
             { "Africa/Maputo", Africa_Central },
@@ -1474,11 +1463,13 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "Pacific/Marquesas", Marquesas },
             { "America/Aruba", Atlantic },
             { "America/North_Dakota/Center", America_Central },
+            { "PNT", America_Mountain },
             { "America/Cayman", America_Eastern },
             { "Asia/Ulaanbaatar", Mongolia },
             { "Asia/Baghdad", Arabian },
             { "Europe/San_Marino", Europe_Central },
             { "America/Indiana/Tell_City", America_Central },
+            { "BST", Bangladesh },
             { "America/Tijuana", America_Pacific },
             { "Pacific/Saipan", Chamorro },
             { "SystemV/YST9", Gambier },
@@ -1490,6 +1481,7 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "America/Argentina/San_Luis", Argentina_Western },
             { "America/Santiago", Chile },
             { "Asia/Baku", Azerbaijan },
+            { "ART", Europe_Eastern },
             { "America/Argentina/Ushuaia", Argentina },
             { "Atlantic/Reykjavik", GMT },
             { "Africa/Brazzaville", Africa_Western },
@@ -1502,31 +1494,12 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "Asia/Bangkok", Indochina },
             { "Africa/Dar_es_Salaam", Africa_Eastern },
             { "Atlantic/Madeira", Europe_Western },
-            { "Antarctica/Palmer",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "America/Thunder_Bay", America_Eastern },
             { "Africa/Addis_Ababa", Africa_Eastern },
+            { "AST", Alaska },
             { "Europe/Uzhgorod", Europe_Eastern },
             { "America/Indiana/Marengo", America_Eastern },
             { "America/Creston", America_Mountain },
-            { "America/Punta_Arenas",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "America/Mexico_City", America_Central },
             { "Antarctica/Vostok", Vostok },
             { "Europe/Andorra", Europe_Central },
@@ -1538,6 +1511,7 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "Atlantic/South_Georgia", South_Georgia },
             { "Europe/Lisbon", Europe_Western },
             { "Asia/Harbin", China },
+            { "PRT", Atlantic },
             { "Europe/Oslo", Europe_Central },
             { "Asia/Novokuznetsk", Krasnoyarsk },
             { "CST6CDT", America_Central },
@@ -1554,6 +1528,7 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "Pacific/Tarawa", Gilbert_Islands },
             { "Africa/Kampala", Africa_Eastern },
             { "Asia/Krasnoyarsk", Krasnoyarsk },
+            { "PST", America_Pacific },
             { "SystemV/EST5", America_Eastern },
             { "America/Edmonton", America_Mountain },
             { "Europe/Podgorica", Europe_Central },
@@ -1621,23 +1596,15 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "America/Scoresbysund", Greenland_Eastern },
             { "Africa/Harare", Africa_Central },
             { "America/Nome", Alaska },
+            { "NST", New_Zealand },
             { "Europe/Tallinn", Europe_Eastern },
             { "Africa/Khartoum", Africa_Central },
             { "Africa/Johannesburg", Africa_Southern },
+            { "EAT", Africa_Eastern },
             { "Africa/Bangui", Africa_Western },
             { "Europe/Belgrade", Europe_Central },
             { "Africa/Bissau", GMT },
             { "Asia/Tehran", Iran },
-            { "Europe/Astrakhan",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Africa/Juba", Africa_Eastern },
             { "America/Campo_Grande", Amazon },
             { "America/Belem", Brasilia },
@@ -1653,6 +1620,7 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "America/Whitehorse", America_Pacific },
             { "Pacific/Noumea", New_Caledonia },
             { "Asia/Tbilisi", Georgia },
+            { "ECT", Europe_Central },
             { "America/Montreal", America_Eastern },
             { "Asia/Makassar", Indonesia_Central },
             { "America/Argentina/San_Juan", Argentina },
@@ -1666,16 +1634,6 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "Asia/Khandyga", Yakutsk },
             { "Asia/Kuala_Lumpur", Malaysia },
             { "Asia/Thimphu", Bhutan },
-            { "Asia/Famagusta",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Asia/Rangoon", Myanmar },
             { "Europe/Bratislava", Europe_Central },
             { "Asia/Calcutta", India },
@@ -1684,17 +1642,8 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "Indian/Cocos", Cocos },
             { "Pacific/Tongatapu", Tonga },
             { "SystemV/YST9YDT", Alaska },
-            { "Europe/Ulyanovsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "America/Merida", America_Central },
+            { "CAT", Africa_Central },
             { "America/St_Kitts", Atlantic },
             { "Arctic/Longyearbyen", Europe_Central },
             { "America/Fort_Nelson", America_Mountain },
@@ -1705,16 +1654,6 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "SystemV/PST8PDT", America_Pacific },
             { "Africa/Monrovia", GMT },
             { "Asia/Ust-Nera", Vladivostok },
-            { "Asia/Srednekolymsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "America/North_Dakota/New_Salem", America_Central },
             { "Australia/Melbourne", Australia_Eastern },
             { "Asia/Irkutsk", Irkutsk },
